/****************************************************************************
 *   Copyright (C) 2004 by Arboretum Systems, Inc.                          *
 *   Technical administrator: Alain Mazy, hav@mazy.be                       *
 *   Lead program designer: Georges Jaroslaw, gjaro@arboretum.com           *
 *                                                                          *
 *   HyperEngine-AV is a video, audio and text editor that can be used to   *
 *   record, import, edit, process and arrange together video, sound and    *
 *   text. These are all achieved in the program's free-form document       *
 *   window, with no limitations to the number of tracks.                   *
 *   The purpose of this program is to provide to users at all levels of    *
 *   expertise a readily accessible tool enabling them to create movies,    *
 *   slide shows or presentations.                                          *
 *                                                                          *
 *   HyperEngine-AV itself is free software. However, plug-ins that can be  *
 *   used as add-ons to HyperEngine-AV may or may not be free software, at  *
 *   the discretion of each plug-in developer and as specified by these     *
 *   plug-ins' respective licenses.                                         *
 *   You can redistribute HyperEngine-AV itself and/or modify it under the  *
 *   terms of the GNU General Public License as published by the Free       *
 *   Software Foundation; either version 2 of the License, or (at your      *
 *   option) any later version.                                             *
 *                                                                          *
 *   HyperEngine-AV is distributed in the hope that it will be useful, but  *
 *   WITHOUT ANY WARRANTY; without even the implied warranty of             *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *   GNU General Public License for all applicable details.                 *
 *                                                                          *
 *   You should have received a copy of the GNU General Public License      *
 *   along with this program; if not, write to:                             *
 *   Free Software Foundation, Inc.,                                        *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.              *
 ****************************************************************************/

#import <AppKit/AppKit.h>
#import "MIMontageDocument.h"
#import "MIPaletteController.h"
#import "MIMontagePalette.h"
#import "MIMovie.h"

#ifdef DEBUG
//#define USE_NSQUICKDRAWVIEW 1
#endif

@interface MIFullScreenVideoWindow : NSPanel {
	NSTrackingRectTag 			fTrackingRect;
	NSTimer						*fTimer;
}

- (void)showMenuBarUnderMouse:(BOOL)flag;

@end

@interface MIViewerController : MIMontagePalette {
    // the windows where video is played
    MIFullScreenVideoWindow		*fFullScreenVideoWindow;

    // caches for menu items that reflect active video window
    NSMenuItem 					*fHalfSizeMenuItem;
    NSMenuItem 					*fNormalSizeMenuItem;
    NSMenuItem 					*fDoubleSizeMenuItem;
    NSMenuItem 					*fFullScreenMenuItem;
    NSMenuItem 					*fHideMenuItem;

#ifndef USE_NSQUICKDRAWVIEW
	IBOutlet NSMovieView		*fMovieView;
#else
	IBOutlet NSQuickDrawView	*fQDView;
	Movie						fQTMovie;
#endif
	IBOutlet NSView				*fMovieViewContainer;
	NSMovieView					*fFullScreenMovieView;
	float						fMagnification;
	float						fCurrentMagnification;
	MIMovie						*fMovie;
	BOOL						fShouldIgnoreNotifications;
}

+ (MIViewerController*)sharedViewerController;

- (float)magnification;
- (void)setMagnification:(float)magnification;
- (void)setMagnification:(float)magnification forDocument:(MIMontageDocument*)document;
- (void)setWindowFrameTopLeftCorner:(NSPoint)point;

- (void)setFullScreen:(BOOL)fullScreen;
- (BOOL)isFullScreen;

- (void)setMovie:(Movie)movie;
- (Movie)movie;
- (NSMovieView*)movieView;
	
- (IBAction)viewBackstageHalfx:(id)sender;
- (IBAction)viewBackstage1x:(id)sender;
- (IBAction)viewBackstage2x:(id)sender;
- (IBAction)viewFullScreen:(id)sender;

- (BOOL)shouldIgnoreNotifications;
- (void)setShouldIgnoreNotifications:(BOOL)flag;

- (void)currentDocumentChanged:(NSNotification*)notification;	

@end

